summaryrefslogtreecommitdiffstats
path: root/video/hwdec.h
diff options
context:
space:
mode:
Diffstat (limited to 'video/hwdec.h')
-rw-r--r--video/hwdec.h18
1 files changed, 15 insertions, 3 deletions
diff --git a/video/hwdec.h b/video/hwdec.h
index ca18340ae1..149cd81bae 100644
--- a/video/hwdec.h
+++ b/video/hwdec.h
@@ -1,14 +1,26 @@
#ifndef MP_HWDEC_H_
#define MP_HWDEC_H_
+struct mp_image_pool;
+
+struct mp_hwdec_ctx {
+ void *priv; // for free use by hwdec implementation
+
+ // API-specific, not needed by all backends.
+ struct mp_vdpau_ctx *vdpau_ctx;
+ struct mp_vaapi_ctx *vaapi_ctx;
+};
+
// Used to communicate hardware decoder API handles from VO to video decoder.
// The VO can set the context pointer for supported APIs.
struct mp_hwdec_info {
- struct mp_vdpau_ctx *vdpau_ctx;
- struct mp_vaapi_ctx *vaapi_ctx;
+ // (Since currently only 1 hwdec API is loaded at a time, this pointer
+ // simply maps to the loaded one.)
+ struct mp_hwdec_ctx *hwctx;
+
// Can be used to lazily load a requested API.
// api_name is e.g. "vdpau" (like the fields above, without "_ctx")
// Can be NULL, is idempotent, caller checks _ctx fields for success/access.
// Due to threading, the callback is the only code that is allowed to
// change fields in this struct after initialization.
void (*load_api)(struct mp_hwdec_info *info, const char *api_name);
@@ -1,14 +1,26 @@
// Can be used to lazily load a requested API.
// api_name is e.g. "vdpau" (like the fields above, without "_ctx")
- // Can be NULL, is idempotent, caller checks _ctx fields for success/access.
+ // Can be NULL, is idempotent, caller checks hwctx fields for success/access.
// Due to threading, the callback is the only code that is allowed to
// change fields in this struct after initialization.